@@ -3,7 +3,7 @@ from django.shortcuts import render
 from .models import Post, CATEGORY
 from django.views import generic
 from hitcount.views import HitCountDetailView
-from _data.blog import context as c
+from _data import zenblog_contents
 from .forms import Search
 from util_demian import utils
 
@@ -28,23 +28,21 @@ def home(request):
     """
     모델의 CATEGORY를 context에 전달하면 category_pattern.html을 할당하여 보여준다.
     """
-    context = {
-        'category': CATEGORY,
-    }
-    return render(request, 'zenblog/index.html', context)
+    c = zenblog_contents.context
+    c['category'] = CATEGORY
+    logger.info(c)
+    return render(request, 'zenblog/index.html', c)
 
 
 def about(request):
-    context = {
-        'about': c['about'],
-    }
-    return render(request, 'zenblog/about.html', context)
+    c = blog.context
+    logger.info(c)
+    return render(request, 'zenblog/about.html', c)
 
 
 def contact(request):
-    context = {
-    }
-    return render(request, 'zenblog/contact.html', context)
+    c = blog.context
+    return render(request, 'zenblog/contact.html', c)
 
 
 class Category(generic.ListView):
